@@ -1,4 +1,5 @@
 import re
+import warnings
 from datetime import datetime, timedelta, tzinfo
 from enum import Enum
 from typing import List, Optional, Union, Dict
@@ -12,6 +13,9 @@ from pydantic import validator, Field
 from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway, timezone_validator, datetime_to_timestamp
 
 
+warnings.warn('\n\nBackend module is deprecated. Migrate to access_service for v2.\n', DeprecationWarning, stacklevel=2)
+
+
 class MediumType(str, Enum):
     lpr = "lpr"
     nfc = "nfc"
@@ -161,6 +165,10 @@ class AccessRequest(OpenModuleModel):
     gateway: Optional[Gateway] = None
     medium_type: MediumType
     medium_id: str = Field(..., alias="id")
+    timestamp: datetime = Field(default_factory=lambda: datetime.utcnow())
+
+    _tz_timestamp = timezone_validator("timestamp")
+
 
     class Config:
         # allows setting attributes both via the alias, and the field name.
@@ -205,6 +213,13 @@ class CountMessage(ZMQMessage):
     previous_medium_id: Optional[str] = Field(None,  # medium_changed, medium_id_changed error
                                               alias="previous_medium_id")
     chosen: Optional[dict]  # choose_random error
+    # is null for entry movements and for double exit movements
+    entry_datetime: Optional[datetime] = Field(default=None, alias="start")
+    # indicates if a movement is reversed to the direction of the gate
+    backward: Optional[bool] = Field(default=None, alias="backwards")
+
+    _tz_entry_datetime = timezone_validator("entry_datetime")
+
 
     class Config:
         # allows setting attributes both via the alias, and the field name.
@@ -219,9 +234,6 @@ class SessionStartMessage(ZMQMessage):
     user_id: Optional[str]
     zone_id: str
     cost_table: dict
-    clearing: Optional[str]
-    access_infos: Optional[dict]
-    serviceable: bool
 
     entry_time: datetime
     entry_data: Dict
@@ -235,20 +247,57 @@ class SessionFinishMessage(ZMQMessage):
     id: str
     user_id: Optional[str]
     zone_id: str
-    cost_table: dict
-    clearing: Optional[str]
-    access_infos: Optional[dict]
-    serviceable: bool
 
     entry_time: datetime
     entry_data: Dict
     exit_time: datetime
     exit_data: Dict
 
-    payment_lock_at: Optional[datetime]
-    payment_lock_until: Optional[datetime]
-
     _tz_entry_time = timezone_validator("entry_time")
     _tz_exit_time = timezone_validator("exit_time")
-    _tz_payment_lock_at = timezone_validator("payment_lock_at")
-    _tz_payment_lock_until = timezone_validator("payment_lock_until")
+
+
+class SessionDeleteMessage(ZMQMessage):
+    type: str = "delete"
+
+    id: str
+    user_id: Optional[str]
+    zone_id: Optional[str]
+    reason: str
+    delete_time: datetime
+
+    entry_time: Optional[datetime]
+    entry_data: Optional[Dict]
+    exit_time: Optional[datetime]
+    exit_data: Optional[Dict]
+
+    _tz_delete_time = timezone_validator("delete_time")
+    _tz_entry_time = timezone_validator("entry_time")
+    _tz_exit_time = timezone_validator("exit_time")
+
+
+class SessionExitWithoutEntryMessage(ZMQMessage):
+    type: str = "exit_without_entry"
+
+    id: str  # id of incorrect session
+    user_id: Optional[str]
+
+    exit_time: datetime
+    exit_data: Dict
+
+    _tz_exit_time = timezone_validator("exit_time")
+
+
+# Double entry of vehicle
+class SessionIncompleteMessage(ZMQMessage):
+    type: str = "incomplete"
+
+    id: str  # id of incorrect session
+    user_id: Optional[str]
+    zone_id: str
+    related_session_id: str  # id of newly created session which caused the double entry
+
+    entry_time: datetime
+    entry_data: Dict
+
+    _tz_entry_time = timezone_validator("entry_time")
