@@ -1,6 +1,6 @@
+from enum import Enum
 from typing import Optional, List, Iterable, Union
 
-from openmodule.models.backend import MediumType
 from openmodule.models.base import OpenModuleModel
 
 
@@ -11,10 +11,27 @@ def _truncate(x):
         return x
 
 
+class MediumType(str, Enum):
+    lpr = "lpr"
+    nfc = "nfc"
+    pin = "pin"
+    qr = "qr"
+    regex = "regex"
+
+
 class Medium(OpenModuleModel):
     id: str
     type: MediumType
 
+    def __eq__(self, other):
+        if isinstance(other, Medium):
+            return self.id == other.id and self.type == other.type
+        else:
+            return False
+
+    def __hash__(self):
+        return hash((self.id, self.type))
+
     def __str__(self):
         return f"{self.type}:{_truncate(self.id)}"
 
@@ -55,6 +72,15 @@ class LPRMedium(Medium):
     def __str__(self):
         return f"{self.type}:[{self.country.code}]{_truncate(self.id)}"
 
+    def __eq__(self, other):
+        if isinstance(other, LPRMedium):
+            return self.id == other.id and self.type == other.type and self.country.code == other.country.code
+        else:
+            return False
+
+    def __hash__(self):
+        return hash((self.id, self.type, self.country.code))
+
 
 class MakeModel(OpenModuleModel):
     make: str
@@ -73,6 +99,12 @@ class PresenceAllIds(OpenModuleModel):
     pin: Optional[List[Medium]]
 
 
+class EnterDirection(str, Enum):
+    forward = "forward"
+    backward = "backward"
+    unknown = "unknown"
+
+
 class Vehicle(OpenModuleModel):
     id: int
     lpr: Optional[LPRMedium]
@@ -80,7 +112,8 @@ class Vehicle(OpenModuleModel):
     nfc: Optional[Medium]
     pin: Optional[Medium]
     make_model: Optional[MakeModel]
-    all_ids: PresenceAllIds
+    all_ids: PresenceAllIds = []
+    enter_direction: EnterDirection = EnterDirection.unknown
 
     def iterate_media(self) -> Iterable[Union[Medium, LPRMedium]]:
         """
@@ -95,6 +128,9 @@ class Vehicle(OpenModuleModel):
         if self.pin:
             yield self.pin
 
+    def has_media(self):
+        return bool(self.lpr or self.qr or self.nfc or self.pin)
+
     def __str__(self):
         media = ", ".join(str(x) for x in [self.lpr, self.qr, self.nfc] if x)
         if media:
