@@ -4,11 +4,11 @@ from unittest import TestCase
 from dateutil.tz import gettz, tzutc
 from sqlalchemy.exc import StatementError
 
+from tests.database_models_test import DatabaseTimezoneTestModel
 from openmodule.config import database_folder
 from openmodule.database.database import Database
 from openmodule.models.base import OpenModuleModel, timezone_validator
 from openmodule_test.database import SQLiteTestMixin
-from openmodule_test.database_models import DatabaseTimezoneTestModel
 
 
 class TimezoneCheckTest(TestCase):
@@ -40,7 +40,7 @@ class TimezoneCheckTest(TestCase):
 
 
 class DatabaseDatetimeTest(SQLiteTestMixin):
-    alembic_path = "../tests/test_database_data"
+    alembic_path = "../tests/test_database"
 
     def test_sqlite_timezone(self):
         with self.assertRaises(StatementError) as e:
@@ -51,6 +51,6 @@ class DatabaseDatetimeTest(SQLiteTestMixin):
         self.assertIn("You need to convert a datetime to a naive time", str(e.exception))
 
         with self.database as db:
-            now = datetime.now()
+            now = datetime.utcnow()
             model = DatabaseTimezoneTestModel(tz_datetime=now)
             db.add(model)
